scripts/uninstall.py

changeset 7960
e8fc383322f7
parent 7923
91e843545d9a
child 8243
cc717c2ae956
--- a/scripts/uninstall.py	Tue Jan 05 18:28:31 2021 +0100
+++ b/scripts/uninstall.py	Wed Jan 06 13:47:01 2021 +0100
@@ -3,11 +3,11 @@
 
 # Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the uninstall script for eric6.
 #
 
 """
-Uninstallation script for the eric6 IDE and all eric6 related tools.
+Uninstallation script for the eric IDE and all eric related tools.
 """
 
 import sys
@@ -57,11 +57,11 @@
 try:
     from eric6config import getConfig
 except ImportError:
-    print("The eric6 IDE doesn't seem to be installed. Aborting.")
+    print("The eric IDE doesn't seem to be installed. Aborting.")
     exit(1)
 except SyntaxError:
     # an incomplete or old config file was found
-    print("The eric6 IDE seems to be installed incompletely. Aborting.")
+    print("The eric IDE seems to be installed incompletely. Aborting.")
     exit(1)
 
 
@@ -461,7 +461,7 @@
         if opt == "-h":
             usage(0)
     
-    print("\nUninstalling eric6 ...")
+    print("\nUninstalling eric ...")
     uninstallEric()
     print("\nUninstallation complete.")
     print()
@@ -3,11 +3,11 @@
 # Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is the uninstall script for eric6.
+# This is the uninstall script for eric.
 #
 

eric ide

mercurial